@@ -1,10 +1,4 @@
-#[cfg(feature = "dlopen")]
-use crate::LIB;
-#[cfg(all(feature = "dlopen", feature = "metadata"))]
-use crate::UUID;
-use dlib::ffi_dispatch;
-#[cfg(not(feature = "dlopen"))]
-use jack_sys::*;
+use jack_sys as j;
 use std::fmt::Debug;
 use std::sync::Arc;
 use std::{ffi, fmt, ptr};
@@ -34,14 +28,13 @@ use crate::{
 /// };
 /// ```
 
-pub type InternalClientID = jack_sys::jack_intclient_t;
+pub type InternalClientID = j::jack_intclient_t;
 
-#[allow(dead_code)]
-pub struct Client {
-    inner: *mut jack_sys::jack_client_t,
-    life: Arc<()>,
-    property_change_handler: Option<Box<dyn PropertyChangeHandler>>,
-}
+pub struct Client(
+    *mut j::jack_client_t,
+    Arc<()>,
+    Option<Box<dyn PropertyChangeHandler>>,
+);
 
 unsafe impl Send for Client {}
 unsafe impl Sync for Client {}
@@ -55,50 +48,22 @@ impl Client {
     /// errors when attempting to opening. To access these, check the returned `ClientStatus`.
     pub fn new(client_name: &str, options: ClientOptions) -> Result<(Self, ClientStatus), Error> {
         let _m = CREATE_OR_DESTROY_CLIENT_MUTEX.lock().unwrap();
-        #[cfg(feature = "dlopen")]
-        let lib = crate::LIB_RESULT
-            .as_ref()
-            .map_err(|e| Error::LoadLibraryError(format!("{}", e)))?;
         unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                lib,
-                jack_set_error_function,
-                Some(error_fn)
-            );
-            ffi_dispatch!(
-                feature = "dlopen",
-                lib,
-                jack_set_info_function,
-                Some(info_fn)
-            );
+            jack_sys::jack_set_error_function(Some(error_handler));
+            jack_sys::jack_set_info_function(Some(info_handler));
         }
         sleep_on_test();
         let mut status_bits = 0;
         let client = unsafe {
             let client_name = ffi::CString::new(client_name).unwrap();
-            ffi_dispatch!(
-                feature = "dlopen",
-                lib,
-                jack_client_open,
-                client_name.as_ptr(),
-                options.bits(),
-                &mut status_bits
-            )
+            j::jack_client_open(client_name.as_ptr(), options.bits(), &mut status_bits)
         };
         sleep_on_test();
         let status = ClientStatus::from_bits(status_bits).unwrap_or_else(ClientStatus::empty);
         if client.is_null() {
             Err(Error::ClientError(status))
         } else {
-            Ok((
-                Client {
-                    inner: client,
-                    life: Arc::default(),
-                    property_change_handler: None,
-                },
-                status,
-            ))
+            Ok((Client(client, Arc::default(), None), status))
         }
     }
 
@@ -119,8 +84,7 @@ impl Client {
     /// The sample rate of the JACK system, as set by the user when jackd was
     /// started.
     pub fn sample_rate(&self) -> usize {
-        let srate =
-            unsafe { ffi_dispatch!(feature = "dlopen", LIB, jack_get_sample_rate, self.raw()) };
+        let srate = unsafe { j::jack_get_sample_rate(self.raw()) };
         srate as usize
     }
 
@@ -130,7 +94,7 @@ impl Client {
     /// clients as a percentage of the real time available per cycle determined by the buffer size
     /// and sample rate.
     pub fn cpu_load(&self) -> f32 {
-        let load = unsafe { ffi_dispatch!(feature = "dlopen", LIB, jack_cpu_load, self.raw()) };
+        let load = unsafe { j::jack_cpu_load(self.raw()) };
         load as f32
     }
 
@@ -140,7 +104,7 @@ impl Client {
     /// `NAME_NOT_UNIQUE`.
     pub fn name(&self) -> &str {
         unsafe {
-            let ptr = ffi_dispatch!(feature = "dlopen", LIB, jack_get_client_name, self.raw());
+            let ptr = j::jack_get_client_name(self.raw());
             let cstr = ffi::CStr::from_ptr(ptr);
             cstr.to_str().unwrap()
         }
@@ -149,7 +113,7 @@ impl Client {
     /// The current maximum size that will every be passed to the process
     /// callback.
     pub fn buffer_size(&self) -> Frames {
-        unsafe { ffi_dispatch!(feature = "dlopen", LIB, jack_get_buffer_size, self.raw()) }
+        unsafe { j::jack_get_buffer_size(self.raw()) }
     }
 
     /// Change the buffer size passed to the process callback.
@@ -158,15 +122,7 @@ impl Client {
     /// callback functions before restarting the process cycle. This will cause a gap in the audio
     /// flow, so it should only be done at appropriate stopping points.
     pub fn set_buffer_size(&self, n_frames: Frames) -> Result<(), Error> {
-        let res = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_set_buffer_size,
-                self.raw(),
-                n_frames
-            )
-        };
+        let res = unsafe { j::jack_set_buffer_size(self.raw(), n_frames) };
         match res {
             0 => Ok(()),
             _ => Err(Error::SetBufferSizeError),
@@ -179,13 +135,13 @@ impl Client {
     ///
     /// * Deallocates, not realtime safe.
     #[cfg(feature = "metadata")]
-    pub fn uuid(&self) -> jack_sys::jack_uuid_t {
+    pub fn uuid(&self) -> j::jack_uuid_t {
         unsafe {
-            let mut uuid: jack_sys::jack_uuid_t = Default::default();
-            let uuid_s = ffi_dispatch!(feature = "dlopen", LIB, jack_client_get_uuid, self.raw());
+            let mut uuid: j::jack_uuid_t = Default::default();
+            let uuid_s = j::jack_client_get_uuid(self.raw());
             assert!(!uuid_s.is_null());
-            assert_eq!(0, ffi_dispatch!(UUID, jack_uuid_parse, uuid_s, &mut uuid));
-            ffi_dispatch!(feature = "dlopen", LIB, jack_free, uuid_s as _);
+            assert_eq!(0, j::jack_uuid_parse(uuid_s, &mut uuid));
+            j::jack_free(uuid_s as _);
             uuid
         }
     }
@@ -197,26 +153,20 @@ impl Client {
     /// * Allocates & deallocates, not realtime safe.
     pub fn uuid_string(&self) -> String {
         unsafe {
-            let uuid_s = ffi_dispatch!(feature = "dlopen", LIB, jack_client_get_uuid, self.raw());
+            let uuid_s = j::jack_client_get_uuid(self.raw());
             assert!(!uuid_s.is_null());
             let uuid = ffi::CStr::from_ptr(uuid_s)
                 .to_str()
                 .expect("uuid is valid string")
                 .to_string();
-            ffi_dispatch!(feature = "dlopen", LIB, jack_free, uuid_s as _);
+            j::jack_free(uuid_s as _);
             uuid
         }
     }
 
     //helper to get client name from uuid string.
     unsafe fn name_by_uuid_raw(&self, uuid: *const ::libc::c_char) -> Option<String> {
-        let name_ptr = ffi_dispatch!(
-            feature = "dlopen",
-            LIB,
-            jack_get_client_name_by_uuid,
-            self.raw(),
-            uuid
-        );
+        let name_ptr = j::jack_get_client_name_by_uuid(self.raw(), uuid);
         if name_ptr.is_null() {
             None
         } else {
@@ -231,11 +181,10 @@ impl Client {
 
     /// Get the name of a client by its numeric uuid.
     #[cfg(feature = "metadata")]
-    pub fn name_by_uuid(&self, uuid: jack_sys::jack_uuid_t) -> Option<String> {
+    pub fn name_by_uuid(&self, uuid: j::jack_uuid_t) -> Option<String> {
         let mut uuid_s = ['\0' as _; 37]; //jack_uuid_unparse expects an array of length 37
-
         unsafe {
-            ffi_dispatch!(UUID, jack_uuid_unparse, uuid, uuid_s.as_mut_ptr());
+            j::jack_uuid_unparse(uuid, uuid_s.as_mut_ptr());
             self.name_by_uuid_raw(uuid_s.as_ptr())
         }
     }
@@ -267,16 +216,12 @@ impl Client {
         let port_name_pattern_cstr = ffi::CString::new(port_name_pattern.unwrap_or("")).unwrap();
         let type_name_pattern_cstr = ffi::CString::new(type_name_pattern.unwrap_or("")).unwrap();
         let flags = libc::c_ulong::from(flags.bits());
-        let ptr = self.raw();
         unsafe {
-            let ports = ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_get_ports,
-                ptr,
+            let ports = j::jack_get_ports(
+                self.raw(),
                 port_name_pattern_cstr.as_ptr(),
                 type_name_pattern_cstr.as_ptr(),
-                flags
+                flags,
             );
             collect_strs(ports)
         }
@@ -305,58 +250,39 @@ impl Client {
         let port_flags = port_spec.jack_flags().bits();
         let buffer_size = port_spec.jack_buffer_size();
         let pp = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_port_register,
+            j::jack_port_register(
                 self.raw(),
                 port_name_c.as_ptr(),
                 port_type_c.as_ptr(),
                 libc::c_ulong::from(port_flags),
-                buffer_size
+                buffer_size,
             )
         };
         if pp.is_null() {
             Err(Error::PortRegistrationError(port_name.to_string()))
         } else {
-            Ok(unsafe { Port::from_raw(port_spec, self.raw(), pp, Arc::downgrade(&self.life)) })
+            Ok(unsafe { Port::from_raw(port_spec, self.raw(), pp, Arc::downgrade(&self.1)) })
         }
     }
 
     /// Get a `Port` by its port id.
     pub fn port_by_id(&self, port_id: PortId) -> Option<Port<Unowned>> {
-        let pp = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_port_by_id,
-                self.raw(),
-                port_id
-            )
-        };
+        let pp = unsafe { j::jack_port_by_id(self.raw(), port_id) };
         if pp.is_null() {
             None
         } else {
-            Some(unsafe { Port::from_raw(Unowned {}, self.raw(), pp, Arc::downgrade(&self.life)) })
+            Some(unsafe { Port::from_raw(Unowned {}, self.raw(), pp, Arc::downgrade(&self.1)) })
         }
     }
 
     /// Get a `Port` by its port name.
     pub fn port_by_name(&self, port_name: &str) -> Option<Port<Unowned>> {
         let port_name = ffi::CString::new(port_name).unwrap();
-        let pp = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_port_by_name,
-                self.raw(),
-                port_name.as_ptr()
-            )
-        };
+        let pp = unsafe { j::jack_port_by_name(self.raw(), port_name.as_ptr()) };
         if pp.is_null() {
             None
         } else {
-            Some(unsafe { Port::from_raw(Unowned {}, self.raw(), pp, Arc::downgrade(&self.life)) })
+            Some(unsafe { Port::from_raw(Unowned {}, self.raw(), pp, Arc::downgrade(&self.1)) })
         }
     }
 
@@ -384,27 +310,26 @@ impl Client {
         let ffi_client_args = ffi::CString::new(client_args).unwrap();
 
         let mut status_bits = 0;
-        let options: jack_sys::Enum_JackOptions = jack_sys::JackLoadName | jack_sys::JackLoadInit;
+        let options: j::Enum_JackOptions = j::JackLoadName | j::JackLoadInit;
 
         let intclient = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_internal_client_load,
+            j::jack_internal_client_load(
                 self.raw(),
                 ffi_client_name.as_ptr(),
                 options,
                 &mut status_bits,
-                ffi_client_bin.as_ptr() as _,
-                ffi_client_args.as_ptr()
+                ffi_client_bin.as_ptr(),
+                ffi_client_args.as_ptr(),
             )
         };
 
-        if intclient == 0 {
-            let status = ClientStatus::from_bits(status_bits).unwrap_or_else(ClientStatus::empty);
-            Err(Error::ClientError(status))
-        } else {
-            Ok(intclient)
+        match intclient {
+            Some(0) => {
+                let status = ClientStatus::from_bits(status_bits).unwrap_or_else(ClientStatus::empty);
+                Err(Error::ClientError(status))
+            },
+            Some(i) => Ok(i),
+            None => Err(Error::WeakFunctionNotFound("jack_internal_client_load")),
         }
     }
 
@@ -418,13 +343,10 @@ impl Client {
     /// It returns a ClientError on error.
     pub fn unload_internal_client(&self, client: InternalClientID) -> Result<(), Error> {
         let status = unsafe {
-            let status = ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_internal_client_unload,
-                self.raw(),
-                client
-            );
+            let status = match j::jack_internal_client_unload(self.raw(), client) {
+                Some(s) => s,
+                None => return Err(Error::WeakFunctionNotFound("jack_internal_client_unload")),
+            };
             ClientStatus::from_bits_unchecked(status)
         };
         if status.is_empty() {
@@ -437,14 +359,7 @@ impl Client {
     /// The estimated time in frames that has passed since the JACK server began the current process
     /// cycle.
     pub fn frames_since_cycle_start(&self) -> Frames {
-        unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_frames_since_cycle_start,
-                self.raw()
-            )
-        }
+        unsafe { j::jack_frames_since_cycle_start(self.raw()) }
     }
 
     /// The estimated current time in frames. This function is intended for use in other threads
@@ -455,7 +370,7 @@ impl Client {
     /// # TODO
     /// - test
     pub fn frame_time(&self) -> Frames {
-        unsafe { ffi_dispatch!(feature = "dlopen", LIB, jack_frame_time, self.raw()) }
+        unsafe { j::jack_frame_time(self.raw()) }
     }
 
     /// The estimated time in microseconds of the specified frame time
@@ -463,15 +378,7 @@ impl Client {
     /// # TODO
     /// - Improve test
     pub fn frames_to_time(&self, n_frames: Frames) -> Time {
-        unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_frames_to_time,
-                self.raw(),
-                n_frames
-            )
-        }
+        unsafe { j::jack_frames_to_time(self.raw(), n_frames) }
     }
 
     /// The estimated time in frames for the specified system time.
@@ -479,23 +386,12 @@ impl Client {
     /// # TODO
     /// - Improve test
     pub fn time_to_frames(&self, t: Time) -> Frames {
-        unsafe { ffi_dispatch!(feature = "dlopen", LIB, jack_time_to_frames, self.raw(), t) }
+        unsafe { j::jack_time_to_frames(self.raw(), t) }
     }
 
     /// Returns `true` if the port `port` belongs to this client.
     pub fn is_mine<PS: PortSpec>(&self, port: &Port<PS>) -> bool {
-        matches!(
-            unsafe {
-                ffi_dispatch!(
-                    feature = "dlopen",
-                    LIB,
-                    jack_port_is_mine,
-                    self.raw(),
-                    port.raw()
-                )
-            },
-            1
-        )
+        matches!(unsafe { j::jack_port_is_mine(self.raw(), port.raw()) }, 1)
     }
 
     /// Toggle input monitoring for the port with name `port_name`.
@@ -510,13 +406,10 @@ impl Client {
     ) -> Result<(), Error> {
         let port_name_cstr = ffi::CString::new(port_name).unwrap();
         let res = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_port_request_monitor_by_name,
+            j::jack_port_request_monitor_by_name(
                 self.raw(),
                 port_name_cstr.as_ptr(),
-                if enable_monitor { 1 } else { 0 }
+                if enable_monitor { 1 } else { 0 },
             )
         };
         match res {
@@ -544,7 +437,7 @@ impl Client {
     //         true => 0,
     //         false => 1,
     //     };
-    //     match unsafe { jack_sys::jack_set_freewheel(self.raw(), onoff) } {
+    //     match unsafe { j::jack_set_freewheel(self.raw(), onoff) } {
     //         0 => Ok(()),
     //         _ => Err(Error::FreewheelError),
     //     }
@@ -574,16 +467,8 @@ impl Client {
         let source_cstr = ffi::CString::new(source_port).unwrap();
         let destination_cstr = ffi::CString::new(destination_port).unwrap();
 
-        let res = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_connect,
-                self.raw(),
-                source_cstr.as_ptr(),
-                destination_cstr.as_ptr()
-            )
-        };
+        let res =
+            unsafe { j::jack_connect(self.raw(), source_cstr.as_ptr(), destination_cstr.as_ptr()) };
         match res {
             0 => Ok(()),
             ::libc::EEXIST => Err(Error::PortAlreadyConnected(
@@ -620,15 +505,7 @@ impl Client {
 
     /// Remove all connections to/from the port.
     pub fn disconnect<PS>(&self, port: &Port<PS>) -> Result<(), Error> {
-        let res = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_port_disconnect,
-                self.raw(),
-                port.raw()
-            )
-        };
+        let res = unsafe { j::jack_port_disconnect(self.raw(), port.raw()) };
         match res {
             0 => Ok(()),
             _ => Err(Error::PortDisconnectionError),
@@ -636,15 +513,7 @@ impl Client {
     }
 
     pub fn unregister_port<PS>(&self, port: Port<PS>) -> Result<(), Error> {
-        let res = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_port_unregister,
-                self.raw(),
-                port.raw()
-            )
-        };
+        let res = unsafe { j::jack_port_unregister(self.raw(), port.raw()) };
         match res {
             0 => Ok(()),
             _ => Err(Error::PortDisconnectionError),
@@ -669,14 +538,7 @@ impl Client {
         let source_port = ffi::CString::new(source_port).unwrap();
         let destination_port = ffi::CString::new(destination_port).unwrap();
         let res = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_disconnect,
-                self.raw(),
-                source_port.as_ptr(),
-                destination_port.as_ptr()
-            )
+            j::jack_disconnect(self.raw(), source_port.as_ptr(), destination_port.as_ptr())
         };
         match res {
             0 => Ok(()),
@@ -691,21 +553,15 @@ impl Client {
     /// * This function may only be called in a buffer size callback.
     pub unsafe fn type_buffer_size(&self, port_type: &str) -> usize {
         let port_type = ffi::CString::new(port_type).unwrap();
-        ffi_dispatch!(
-            feature = "dlopen",
-            LIB,
-            jack_port_type_get_buffer_size,
-            self.raw(),
-            port_type.as_ptr()
-        )
+        j::jack_port_type_get_buffer_size(self.raw(), port_type.as_ptr())
     }
 
     /// Expose the underlying ffi pointer.
     ///
     /// This is mostly for use within the jack crate itself.
     #[inline(always)]
-    pub fn raw(&self) -> *mut jack_sys::jack_client_t {
-        self.inner
+    pub fn raw(&self) -> *mut j::jack_client_t {
+        self.0
     }
 
     /// Create a `Client` from an ffi pointer.
@@ -714,12 +570,8 @@ impl Client {
     ///
     /// # Safety
     /// It is unsafe to create a `Client` from a raw pointer.
-    pub unsafe fn from_raw(p: *mut jack_sys::jack_client_t) -> Self {
-        Client {
-            inner: p,
-            life: Arc::default(),
-            property_change_handler: None,
-        }
+    pub unsafe fn from_raw(p: *mut j::jack_client_t) -> Self {
+        Client(p, Arc::default(), None)
     }
 
     /// Get a `Transport` object associated with this client.
@@ -728,8 +580,8 @@ impl Client {
     /// * The transport methods will only work during this client's lifetime.
     pub fn transport(&self) -> Transport {
         Transport {
-            client_ptr: self.inner,
-            client_life: Arc::downgrade(&self.life),
+            client_ptr: self.0,
+            client_life: Arc::downgrade(&self.1),
         }
     }
 
@@ -745,17 +597,14 @@ impl Client {
         &mut self,
         handler: H,
     ) -> Result<(), Error> {
-        assert!(self.property_change_handler.is_none());
+        assert!(self.2.is_none());
         let handler = Box::into_raw(Box::new(handler));
         unsafe {
-            self.property_change_handler = Some(Box::from_raw(handler));
-            if ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_set_property_change_callback,
+            self.2 = Some(Box::from_raw(handler));
+            if j::jack_set_property_change_callback(
                 self.raw(),
                 Some(crate::properties::property_changed::<H>),
-                std::mem::transmute::<_, _>(handler)
+                std::mem::transmute::<_, _>(handler),
             ) == 0
             {
                 Ok(())
@@ -774,10 +623,10 @@ impl Drop for Client {
         debug_assert!(!self.raw().is_null()); // Rep invariant
                                               // Close the client
         sleep_on_test();
-        let res = unsafe { ffi_dispatch!(feature = "dlopen", LIB, jack_client_close, self.raw()) }; // close the client
+        let res = unsafe { j::jack_client_close(self.raw()) }; // close the client
         sleep_on_test();
         assert_eq!(res, 0);
-        self.inner = ptr::null_mut();
+        self.0 = ptr::null_mut();
     }
 }
 
@@ -797,7 +646,7 @@ impl Debug for Client {
 /// callback.
 #[derive(Debug)]
 pub struct ProcessScope {
-    client_ptr: *mut jack_sys::jack_client_t,
+    client_ptr: *mut j::jack_client_t,
 
     // Used to allow safe access to IO port buffers
     n_frames: Frames,
@@ -814,27 +663,13 @@ impl ProcessScope {
     /// from the process callback, and can be used to interpret timestamps generated by
     /// `self.frame_time()` in other threads, with respect to the current process cycle.
     pub fn last_frame_time(&self) -> Frames {
-        unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_last_frame_time,
-                self.client_ptr()
-            )
-        }
+        unsafe { j::jack_last_frame_time(self.client_ptr()) }
     }
 
     /// The estimated time in frames that has passed since the JACK server began the current process
     /// cycle.
     pub fn frames_since_cycle_start(&self) -> Frames {
-        unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_frames_since_cycle_start,
-                self.client_ptr()
-            )
-        }
+        unsafe { j::jack_frames_since_cycle_start(self.client_ptr()) }
     }
 
     /// Provides the internal cycle timing information as used by most of the other time related
@@ -851,14 +686,8 @@ impl ProcessScope {
         let mut next_usecs: Time = 0;
         let mut period_usecs: libc::c_float = 0.0;
 
-        let jack_get_cycle_times_fn = {
-            match *jack_sys::jack_get_cycle_times {
-                Some(f) => f,
-                None => return Err(Error::WeakFunctionNotFound),
-            }
-        };
         let res = unsafe {
-            (jack_get_cycle_times_fn)(
+            (jack_sys::jack_get_cycle_times)(
                 self.client_ptr(),
                 &mut current_frames,
                 &mut current_usecs,
@@ -867,7 +696,8 @@ impl ProcessScope {
             )
         };
         match res {
-            0 => Ok(CycleTimes {
+            None => Err(Error::WeakFunctionNotFound("jack_get_cycle_times")),
+            Some(0) => Ok(CycleTimes {
                 current_frames,
                 current_usecs,
                 next_usecs,
@@ -881,7 +711,7 @@ impl ProcessScope {
     ///
     /// This is mostly for use within the jack crate itself.
     #[inline(always)]
-    pub fn client_ptr(&self) -> *mut jack_sys::jack_client_t {
+    pub fn client_ptr(&self) -> *mut j::jack_client_t {
         self.client_ptr
     }
 
@@ -893,7 +723,7 @@ impl ProcessScope {
     /// # Safety
     /// It is unsafe to create a `ProcessScope` since it may not be valid. For library user's, the
     /// `ProcessScope` is usually passed in as a parameter to a trait's method.
-    pub unsafe fn from_raw(n_frames: Frames, client_ptr: *mut jack_sys::jack_client_t) -> Self {
+    pub unsafe fn from_raw(n_frames: Frames, client_ptr: *mut j::jack_client_t) -> Self {
         ProcessScope {
             n_frames,
             client_ptr,
@@ -910,14 +740,14 @@ pub struct CycleTimes {
     pub period_usecs: libc::c_float,
 }
 
-unsafe extern "C" fn error_fn(msg: *const libc::c_char) {
+unsafe extern "C" fn error_handler(msg: *const libc::c_char) {
     match std::ffi::CStr::from_ptr(msg).to_str() {
         Ok(msg) => log::error!("{}", msg),
         Err(err) => log::error!("failed to parse JACK error: {:?}", err),
     }
 }
 
-unsafe extern "C" fn info_fn(msg: *const libc::c_char) {
+unsafe extern "C" fn info_handler(msg: *const libc::c_char) {
     match std::ffi::CStr::from_ptr(msg).to_str() {
         Ok(msg) => log::info!("{}", msg),
         Err(err) => log::error!("failed to parse JACK error: {:?}", err),
