@@ -1,8 +1,4 @@
-#[cfg(feature = "dlopen")]
-use crate::LIB;
-use dlib::ffi_dispatch;
-#[cfg(not(feature = "dlopen"))]
-use jack_sys::*;
+use jack_sys as j;
 use std::marker::PhantomData;
 use std::{mem, slice};
 
@@ -32,7 +28,7 @@ pub struct MidiOut;
 
 unsafe impl PortSpec for MidiIn {
     fn jack_port_type(&self) -> &'static str {
-        jack_sys::RAW_MIDI_TYPE
+        j::RAW_MIDI_TYPE
     }
 
     fn jack_flags(&self) -> PortFlags {
@@ -86,17 +82,8 @@ impl<'a> MidiIter<'a> {
     }
 
     fn absolute_nth(&self, n: u32) -> Option<RawMidi<'a>> {
-        let mut ev = mem::MaybeUninit::<jack_sys::jack_midi_event_t>::uninit();
-        let res = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_midi_event_get,
-                ev.as_mut_ptr(),
-                self.buffer,
-                n
-            )
-        };
+        let mut ev = mem::MaybeUninit::<j::jack_midi_event_t>::uninit();
+        let res = unsafe { j::jack_midi_event_get(ev.as_mut_ptr(), self.buffer, n) };
         if res != 0 {
             return None;
         }
@@ -110,14 +97,7 @@ impl<'a> MidiIter<'a> {
         if self.buffer.is_null() {
             0
         } else {
-            unsafe {
-                ffi_dispatch!(
-                    feature = "dlopen",
-                    LIB,
-                    jack_midi_get_event_count,
-                    self.buffer
-                ) as usize
-            }
+            unsafe { j::jack_midi_get_event_count(self.buffer) as usize }
         }
     }
 }
@@ -157,7 +137,7 @@ impl<'a> Iterator for MidiIter<'a> {
 
 unsafe impl PortSpec for MidiOut {
     fn jack_port_type(&self) -> &'static str {
-        jack_sys::RAW_MIDI_TYPE
+        j::RAW_MIDI_TYPE
     }
 
     fn jack_flags(&self) -> PortFlags {
@@ -176,7 +156,7 @@ impl Port<MidiOut> {
     pub fn writer<'a>(&'a mut self, ps: &'a ProcessScope) -> MidiWriter<'a> {
         assert_eq!(self.client_ptr(), ps.client_ptr());
         let buffer = unsafe { self.buffer(ps.n_frames()) };
-        unsafe { ffi_dispatch!(feature = "dlopen", LIB, jack_midi_clear_buffer, buffer) };
+        unsafe { j::jack_midi_clear_buffer(buffer) };
         MidiWriter {
             buffer,
             _phantom: PhantomData,
@@ -198,22 +178,12 @@ impl<'a> MidiWriter<'a> {
     /// realtime messages interspersed with other messagse (realtime messages are fine when they
     /// occur on their own, like other messages).
     pub fn write(&mut self, message: &RawMidi) -> Result<(), Error> {
-        let ev = jack_sys::jack_midi_event_t {
+        let ev = j::jack_midi_event_t {
             time: message.time,
             size: message.bytes.len(),
             buffer: message.bytes.as_ptr() as *mut u8,
         };
-        let res = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_midi_event_write,
-                self.buffer,
-                ev.time,
-                ev.buffer,
-                ev.size
-            )
-        };
+        let res = unsafe { j::jack_midi_event_write(self.buffer, ev.time, ev.buffer, ev.size) };
         match res {
             0 => Ok(()),
             _ => Err(Error::NotEnoughSpace),
@@ -225,14 +195,7 @@ impl<'a> MidiWriter<'a> {
     /// If the return value is greater than 0, than the buffer is full.  Currently, the only way
     /// this can happen is if events are lost on port mixdown.
     pub fn lost_count(&self) -> usize {
-        let n = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_midi_get_lost_event_count,
-                self.buffer
-            )
-        };
+        let n = unsafe { j::jack_midi_get_lost_event_count(self.buffer) };
         n as usize
     }
 
@@ -241,14 +204,7 @@ impl<'a> MidiWriter<'a> {
     /// This function returns the current space available, taking into account events already stored
     /// in the port.
     pub fn max_event_size(&self) -> usize {
-        let n = unsafe {
-            ffi_dispatch!(
-                feature = "dlopen",
-                LIB,
-                jack_midi_max_event_size,
-                self.buffer
-            )
-        };
+        let n = unsafe { j::jack_midi_max_event_size(self.buffer) };
         n as usize
     }
 }
